爱在黎明破晓前 (豆瓣)
Description: 爱在黎明破晓前电影简介和剧情介绍,爱在黎明破晓前影评、图片、预告片、影讯、论坛、在线购票
Keywords: 爱在黎明破晓前,Before Sunrise,爱在黎明破晓前影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.109豆瓣电影Top250

# 爱在黎明破晓前 Before Sunrise (1995)

导演: 理查德·林克莱特
编剧: 理查德·林克莱特 / 金·克里桑
主演: 伊桑·霍克 / 朱莉·德尔佩 / 安德莉亚·埃克特 / 汉诺·波西尔 / 卡尔·布拉克施魏格尔 / 特克斯·鲁比诺威茨 / 埃尔尼·曼戈尔德 / 多米尼克·卡斯特尔 / 海蒙·玛丽亚·巴汀格 / 哈拉尔德·魏格莱因 / 汉斯·魏因加特纳 / 彼得·艾利·休默 / 休伯特·法比安·库尔特勒 / 约翰·斯洛斯 / 克里斯蒂安·安科维奇 / 亚当·戈德堡 / 保罗·波伊特
类型: 剧情 / 爱情
制片国家/地区: 美国 / 奥地利 / 瑞士
语言: 英语 / 德语 / 法语
上映日期: 1995-01-27(美国)
片长: 101分钟
又名: 情留半天(港) / 爱在黎明破晓时(台) / 日出之前
IMDb: tt0112471
豆瓣评分
引用
8.8
636640人评价
5星
54.3%
4星
34.8%
3星
9.7%
2星
1.0%
1星
0.3%
好于 98% 爱情片
好于 97% 剧情片
想看 看过
评价:
推荐

## 爱在黎明破晓前的剧情简介 · · · · · ·

美国青年杰西（伊桑·霍克 Ethan Hawke 饰）在火车上偶遇了法国女学生塞琳娜（朱莉·德尔佩 Julie Delpy 饰），两人在火车上交谈甚欢。当火车到达维也纳时，杰西盛情邀请塞琳娜一起在维也纳游览一番，即使杰西翌日便要坐飞机离开。与杰西一见钟情的塞琳娜接受了杰西的邀请。
他们一边游览城市，一边谈论着彼此的过去 ，彼此对生活的感想，两人了解越加深刻。他们非常珍惜这美妙的晚上，这对恋人一起经历了很多浪漫的经历因为他们约定在半年后再见，而此次约会将会在日出之间结束…… ©豆瓣

## 爱在黎明破晓前的演职员 · · · · · · ( 全部 25 )

- 理查德·林克莱特 导演
- 伊桑·霍克 饰 Jesse
- 朱莉·德尔佩 饰 Céline
- 安德莉亚·埃克特 饰 Wife on Train
- 汉诺·波西尔 饰 Husband on Train
- 卡尔·布拉克施魏格尔 演员

## 爱在黎明破晓前的视频和图片 · · · · · · ( 预告片2 | 添加视频评论 | 图片854 · 添加 )

## 爱在黎明破晓前的获奖情况 · · · · · · ( 全部 )

- 第45届柏林国际电影节
- 金熊奖 最佳影片(提名)
- 理查德·林克莱特

- 第45届柏林国际电影节
- 银熊奖 最佳导演
- 理查德·林克莱特

## 喜欢这部电影的人也喜欢 · · · · · ·

  爱在日落黄昏时

  罗马假日

  恋恋笔记本

  重庆森林

  花样年华

  甜蜜蜜

  傲慢与偏见

  爱乐之城

  天使爱美丽

  真爱至上

我要写短评

## 爱在黎明破晓前的短评 · · · · · · ( 全部 170139 条 )

热门 / 最新 / 好友

### 11231 有用 王大根 看过 2016-04-15 22:57:10

我觉得一个更可能的故事是：同一列火车上长相平庸的男女，也许真的能聊得非常非常投契，他们看过一样的书，喜欢同一部电影，讲的笑话能让对方哈哈大笑，甚至能理解彼此的某些小怪癖。但他们的面目是如此模糊啊，两个人的目光都没有在对方的身上停留过，下车的时候，大家也就这样擦过肩去了。

### 8687 有用 大头绿豆 看过 2006-09-23 14:47:17

两个人在试听间里听爱情歌曲的那一段，局促的空间里，想看对方，又有些矜持，目光刚一接触就赶紧离开，那么一段长长的时间，很好。餐厅里互打电话。对话总是很聪明。“很多人结婚的理由比这还少。”

### 6533 有用 眠去 看过 2008-02-08 22:11:48

你之前提到过以后几年的光景，一对夫妻会开始厌恶对方，对彼此的一举一动都了如指掌因此而感到厌烦，我想我会有相反的发展，我对一个人越是了解就越是能真正的去爱他，他会梳某种头发，他会穿哪件T恤，他在某种场合一定会讲的故事，我相信那会是我爱一个人最真实的境界。

### 6193 有用 朝暮雪 看过 2013-08-20 00:25:03

这要是在中国，还没开始就结束了，因为火车上根本没有空位。

### 6517 有用 ふふちゃん 看过 2012-07-05 08:05:08

当年抱着打不开字幕的盗版碟一句一句听写下来台词，一遍一遍读得爱不释手以至烂熟于心，然后我裸考雅思就7分了。。。

> 更多短评 170139条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 爱在黎明破晓前的影评 · · · · · · ( 全部 3172 条 )

热门 / 最新 / 好友
ColinYang 2008-08-10 10:14:55

## 艳遇现象分析

旅行的意义，不单单在沿途的风景，更重要的是在路上遇到的人 这是一部在文艺片界备受推崇的话痨艳遇电影，整部片子唯美，浪漫，自然，真实。没有什么世家情仇，也没有灰姑娘和王子，既不狗血，也不华丽，一切发生的都哪么流畅又令人羡慕，在羡慕完俩人的浪漫一夜之... (展开)
3409 314 301回应 收起
糖罐子 2008-02-10 13:59:00

## 你遇见我，我遇见你，这就是意义

人物：一男一女；时间：相遇之后，天亮以前；地点：维也纳；事件：一场漫无目的游荡，所有的一切清晰直白没有任何想象空间，无关乎情节，只关乎细节。 而他叫什么名字？她又叫什么名字？ 似乎这也只是在最初两人在维也纳下车后出于习惯象征性的告诉对方他叫杰西她叫席琳时随口... (展开)
2743 75 283回应 收起
毛利 2008-06-28 22:52:45

## 在春天，看一部发情电影

友情提示：此文过长，谨慎观看。 这部著名ONS电影终于被我down下来，在一个大雨下得如痴如醉的无聊午后，慢慢看完。 故事有关艳遇，据说艳遇现在很俗，城市大批量产生寂寞男女的时候，大批量的艳遇在各种旅途中应运而生。人人都能体验一见钟情，只要他不是特别差劲，所以艳遇... (展开)
1886 189 194回应 收起
梧桐更兼细雨 2010-05-23 15:50:32

## 《日出之前》（before sunrise）完整台词重译

日出之前（before sunrise）台词翻译 男主角：Ethan Hawke 女主角：Julie Delpy 导演：Richard Linklater 一、 在火车上相识 （一对中年夫妻在用德语吵架，声音越来越响，坐在过道对面的女主角看不进书，皱眉，拿包离开，来到男主角过道的对面，瞥了男主角一眼后，坐下看书... (展开)
1203 13 111回应 收起
Jiong 2008-11-21 08:06:21

## 最简单的爱情却是最难得

这是一部极其动人的爱情片，但却也是一个极其简单的爱情故事：一对男女在火车上相遇，有了好感，一起在维也纳共度一夜，仅此而已。没有什么起伏曲折，没有发生什么让人刻骨铭心的事件将两人简单的感情升华；就只是正常的约会、吃饭、聊天、喝酒。这基本上就是一个没有什么情节... (展开)
902 29 81回应 收起
曾良君 2014-10-25 07:43:38

## 爱情之中没有神明

这篇影评可能有剧透

#以下影评对爱在三部曲都有严重剧透# 尽管这确实是一本浪漫爱情影片，但实际上我们可以这样说，这本电影本质上并不是在讲述一个爱情故事，而是在探讨人与人之间的关系，只不过导演选取了爱情为载体。 当然他并没有别的选择，因为爱情是人与人之间最为复杂和深刻的感情，所以我... (展开)
596 12 24回应 收起
嬗 2008-04-23 20:54:39

## 只爱陌生人

这篇影评可能有剧透

人的一生会遇见几个让你心甘情愿跟他走的陌生人？ 也许有一个，也许有两个，也许你一个也遇不到。 而她遇到了，在那列开往巴黎的火车上。 她告诉他她想成为作家、演员、开一家动物收容站，他告诉她他看见过彩虹里死去的祖母朝他微笑。 我想她应该很喜欢... (展开)
402 19 88回应 收起
makzhou 2005-08-11 11:21:35

## Before Sunrise

Daydream, delusion, limousine, eyelash Oh baby with your pretty face Drop a tear in my wineglass Look at those big eyes See what you mean to me Sweet-cakes and milkshakes I'm delusion angel I'm fantasy parade I want you to know what I think Don't want you t... (展开)
251 18 29回应 收起
林三郎 2008-09-17 12:19:07

## 两个寂寞话痨的谈话节目（经典台词）

两个话痨最后分手的时候，音乐旖旎地扫过他们一起走过的每一个地方，和他们在分道扬镳的两辆车上的安静身影，我开始觉得有一种叫感动的东西在胸腔里发酵。我相信，我喜欢这部电影，它比所有的谈话节目拍得都动人。 记录的一些美妙的台词： 我父亲曾在和我母亲吵架的时候当着我... (展开)
307 10 13回应 收起
邝言 2008-07-02 02:10:22

## 梦醒时总是泪流满面

这篇影评可能有剧透

（一）那天你赴约了吗？ 在《Before Sunset》这部电影的开头，男女主人公九年后重逢，在此后无休无止的对话开始之前，女人说她得先问一个重要的问题：“那天你赴约了吗？” 这个问题还要上溯到九年前，陌生男女在列车上偶然邂逅，擦出了耀眼的火花，燃烧了整整一夜。天亮后，... (展开)
241 8 34回应 收起

> 更多影评 3172篇

添加新讨论

## 讨论区 · · · · · ·

看了不知道多少遍 | 来自辉然.. |  | 2022-11-23 19:47:43
电影中是发生性关系好，还是不发生性关系处理的好？ | 来自_McCall | 58 回应 | 2022-11-22 11:52:55
他们为什么没去看母牛表演？ | 来自暗夜航路 | 9 回应 | 2022-11-20 19:43:57
Celine酷似《老友记》中的Phoebe啊！ | 来自一瓣名豆 | 30 回应 | 2022-11-20 19:41:16
关于草坪啪与没啪 | 来自人生就是一折腾 | 17 回应 | 2022-11-20 19:40:51

> 去这部影片的讨论区（全部362条）

## 关于《爱在黎明破晓前》的问题 · · · · · · ( 全部27个 )

- 主角到底有没有在维也纳公园的草坪上露天干？ 11人回答
- Jesse和selina整一晚怎么没看出有一点儿的困意，再有情趣再难舍难分，眼皮也会沉重吧？ 14人回答

> 全部27个问题

## 在哪儿看这部电影 · · · · · ·

- 优酷视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【容易忽视的好电影】 (影志)
- 【浪漫爱情轻喜】 (影志)
- 【内牛满面】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)

## 谁在看这部电影 · · · · · ·

- 咳嗽的夜鸟
  2分钟前 看过
- importantwin
  3分钟前 想看
- 再见白丝
  3分钟前 想看

895656人看过 / 393206人想看

订阅爱在黎明破晓前的评论:
feed: rss 2.0